@@ -2,12 +2,14 @@ from google.cloud import storage
 from airflow.models import Variable
 from datetime import datetime
 import json
+import pandas as pd
 from dask import dataframe as dd
 
 
 def create_dask_df(database=None,
                    table=None,
-                   gcs_bucket=None):
+                   gcs_bucket=None,
+                   date_columns=None):
 
     curr_date = datetime.now().strftime('%Y-%m-%d')
     filename = f'{table}-extract-{curr_date}.csv'
@@ -21,5 +23,11 @@ def create_dask_df(database=None,
     dt_blob = blob.download_as_text()
     data_types = json.loads(dt_blob)
 
-    ddf = dd.read_csv(data_path, delimiter='|', dtype=data_types)
+    if date_columns:
+        def date_parser(x): return pd.to_datetime(x, errors='coerce')
+        ddf = dd.read_csv(data_path, delimiter='|', dtype=data_types,
+                          parse_dates=date_columns, date_parser=date_parser)
+    else:
+        ddf = dd.read_csv(data_path, delimiter='|', dtype=data_types)
+
     return ddf
