@@ -7,8 +7,7 @@ def load_gcs(project=None,
              database=None,
              table=None,
              gcs_bucket=None,
-             processed=False,
-             in_airflow=True):
+             processed=False):
 
     curr_date = datetime.now().strftime('%Y-%m-%d')
 
@@ -19,7 +18,7 @@ def load_gcs(project=None,
         filename = f'{table}-extract-{curr_date}.csv'
         state = 'raw'
 
-    data_folder = Variable.get('data_folder') if in_airflow else './'
+    data_folder = Variable.get('data_folder')
     data_path = f'{data_folder}/{database}/{table}'
 
     client = storage.Client(project=project)
